aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/man_macro.c
diff options
context:
space:
mode:
authorIngo Schwarze <schwarze@openbsd.org>2017-01-10 13:47:00 +0000
committerIngo Schwarze <schwarze@openbsd.org>2017-01-10 13:47:00 +0000
commit7fc8bcc7ce494daa94a0e6fced0c1d78947c2125 (patch)
tree02cadf682a60bc4693ebf41f5c2c24563478686c /man_macro.c
parentf313579fbb5a5318367521793dc24d2567da2fde (diff)
downloadmandoc-7fc8bcc7ce494daa94a0e6fced0c1d78947c2125.tar.gz
mandoc-7fc8bcc7ce494daa94a0e6fced0c1d78947c2125.tar.zst
mandoc-7fc8bcc7ce494daa94a0e6fced0c1d78947c2125.zip
unify names of AST node flags; no change of cpp output
Diffstat (limited to 'man_macro.c')
-rw-r--r--man_macro.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/man_macro.c b/man_macro.c
index d1533570..7fd17c53 100644
--- a/man_macro.c
+++ b/man_macro.c
@@ -1,4 +1,4 @@
-/* $Id: man_macro.c,v 1.114 2016/01/08 17:48:09 schwarze Exp $ */
+/* $Id: man_macro.c,v 1.115 2017/01/10 13:47:00 schwarze Exp $ */
/*
* Copyright (c) 2008, 2009, 2010, 2011 Kristaps Dzonsons <kristaps@bsd.lv>
* Copyright (c) 2012, 2013, 2014, 2015 Ingo Schwarze <schwarze@openbsd.org>
@@ -95,7 +95,7 @@ man_unscope(struct roff_man *man, const struct roff_node *to)
/* Reached the end of the document? */
- if (to == NULL && ! (n->flags & MAN_VALID)) {
+ if (to == NULL && ! (n->flags & NODE_VALID)) {
if (man->flags & (MAN_BLINE | MAN_ELINE) &&
man_macros[n->tok].flags & MAN_SCOPED) {
mandoc_vmsg(MANDOCERR_BLK_LINE,
@@ -130,7 +130,7 @@ man_unscope(struct roff_man *man, const struct roff_node *to)
man->last = n;
n = n->parent;
- man->last->flags |= MAN_VALID;
+ man->last->flags |= NODE_VALID;
}
/*
@@ -164,7 +164,7 @@ rew_scope(struct roff_man *man, int tok)
for (;;) {
if (n->type == ROFFT_ROOT)
return;
- if (n->flags & MAN_VALID) {
+ if (n->flags & NODE_VALID) {
n = n->parent;
continue;
}
@@ -356,13 +356,13 @@ in_line_eoln(MACRO_PROT_ARGS)
}
/*
* Append MAN_EOS in case the last snipped argument
* ends with a dot, e.g. `.IR syslog (3).'
*/
if (n != man->last &&
mandoc_eos(man->last->string, strlen(man->last->string)))
- man->last->flags |= MAN_EOS;
+ man->last->flags |= NODE_EOS;
/*
* If no arguments are specified and this is MAN_SCOPED (i.e.,
@@ -356,13 +356,13 @@ in_line_eoln(MACRO_PROT_ARGS)
}
/*
- * Append MAN_EOS in case the last snipped argument
+ * Append NODE_EOS in case the last snipped argument
* ends with a dot, e.g. `.IR syslog (3).'
*/